@@ -46,12 +46,14 @@
 #' 
 #' # Fit Bayesian SITAR model 
 #' 
-#' # To avoid mode estimation which takes time, a model fitted to the 
-#' # 'berkeley_mdata' has already been saved as 'berkeley_mfit'. 
-#' # Details on 'berkeley_mdata' and 'berkeley_mfit' are provided in the 
-#' # 'bsitar' function.
+#' # To avoid mode estimation which takes time, the Bayesian SITAR model fit to 
+#' # the 'berkeley_exdata' has been saved as an example fit ('berkeley_exfit').
+#' # See 'bsitar' function for details on 'berkeley_exdata' and 'berkeley_exfit'.
 #' 
-#' model <- berkeley_mfit
+#' # Check and confirm whether model fit object 'berkeley_exfit' exists
+#'  berkeley_exfit <- getNsObject(berkeley_exfit)
+#' 
+#' model <- berkeley_exfit
 #' 
 #' # Population average distance curve
 #' fitted_draws(model, deriv = 0, re_formula = NA)
@@ -72,6 +74,7 @@ fitted_draws.bgmfit <-
            newdata = NULL,
            resp = NULL,
            ndraws = NULL,
+           draw_ids = NULL,
            re_formula = NA,
            allow_new_levels = FALSE,
            sample_new_levels = "uncertainty",
@@ -94,16 +97,45 @@ fitted_draws.bgmfit <-
            verbose = FALSE,
            fullframe = NULL,
            dummy_to_factor = NULL, 
-           usesavedfuns = FALSE,
+           expose_function = FALSE,
+           usesavedfuns = NULL,
            clearenvfuns = NULL,
            envir = NULL,
            ...) {
-   
-  
+    
+    
     if(is.null(envir)) {
+      envir <- model$model_info$envir
+    } else {
       envir <- parent.frame()
     }
     
+    if(is.null(usesavedfuns)) {
+      if(!is.null(model$model_info$exefuns[[1]])) {
+        usesavedfuns <- TRUE
+      } else if(is.null(model$model_info$exefuns[[1]])) {
+        if(expose_function) {
+          model <- expose_model_functions(model, envir = envir)
+          usesavedfuns <- TRUE
+        } else if(!expose_function) {
+          usesavedfuns <- FALSE
+        }
+      }
+    } else {
+      if(!usesavedfuns) {
+        if(expose_function) {
+          model <- expose_model_functions(model, envir = envir)
+          usesavedfuns <- TRUE
+        }
+      } else if(usesavedfuns) {
+        check_if_functions_exists(model, checks = TRUE, 
+                                  usesavedfuns = usesavedfuns)
+      }
+    }
+    
+    check_if_package_installed(model, xcall = NULL)
+    
+    
     if(is.null(ndraws)) {
       ndraws <- brms::ndraws(model)
     }
@@ -195,6 +227,21 @@ fitted_draws.bgmfit <-
     
     if(is.null(test)) return(invisible(NULL))
     
+    
+    if(!isTRUE(
+      check_pkg_version_exists('brms', 
+                               minversion = get_package_minversion('brms'), 
+                               prompt = FALSE,
+                               stop = FALSE,
+                               verbose = FALSE))) {
+      if(is.null(check_if_functions_exists(model, o, model$xcall,
+                                           usesavedfuns = usesavedfuns))) {
+        return(invisible(NULL))
+      }
+    }
+    
+    
+    
     misc <- c("verbose", "usesavedfuns", "clearenvfuns", 
               "envir", "fullframe")
     
@@ -212,6 +259,10 @@ fitted_draws.bgmfit <-
     }
     
     calling.args$object <- full.args$model
+    if(is.null(calling.args$newdata)) {
+      if(!is.null(newdata)) calling.args$newdata <- newdata
+    }
+
 
     . <- do.call(fitted, calling.args)
     
@@ -241,6 +292,9 @@ fitted_draws.bgmfit <-
     }
     
     if(is.null(eval(full.args$clearenvfuns))) {
+      if(is.null(eval(full.args$usesavedfuns))) {
+        full.args$usesavedfuns <- usesavedfuns
+      }
       if(eval(full.args$usesavedfuns)) {
         setcleanup <- TRUE 
       } else {
@@ -250,25 +304,30 @@ fitted_draws.bgmfit <-
       
     # Cleanup environment if requested
     if(setcleanup) {
-      tempgenv <- envir
-      for (oalli in names(oall)) {
-        if(exists(oalli, envir = tempgenv )) {
-          remove(list=oalli, envir = tempgenv)
+      suppressWarnings({
+        tempgenv <- envir
+        for (oalli in names(oall)) {
+          if(exists(oalli, envir = tempgenv )) {
+            remove(list=oalli, envir = tempgenv)
+          }
         }
-      }
-      tempgenv <- test
-      for (oalli in names(oall)) {
-        if(exists(oalli, envir = tempgenv )) {
-          remove(list=oalli, envir = tempgenv)
+        tempgenv <- test
+        for (oalli in names(oall)) {
+          if(exists(oalli, envir = tempgenv )) {
+            remove(list=oalli, envir = tempgenv)
+          }
         }
-      }
+      })
     } # if(setcleanup) {
     
     
     # fullframe
+    full.args$idata_method <- idata_method
+    full.args$fullframe <- eval(full.args$fullframe)
+    
     if(!is.null(eval(full.args$fullframe))) {
       if(eval(full.args$fullframe)) {
-        if(!eval(full.args$fullframe)) {
+        if(!eval(full.args$summary)) {
           stop("fullframe can not be combined with summary = FALSE")
         }
         if(full.args$idata_method == 'm1') {
@@ -285,7 +344,15 @@ fitted_draws.bgmfit <-
       }
     }
     if (!is.na(model$model_info$univariate_by)) {
-      if(full.args$idata_method == 'm2') {
+      if(is.null(full.args$fullframe)) 
+        full.args$fullframe <- fullframe <- FALSE
+      if(full.args$fullframe & full.args$idata_method == 'm1') 
+        setfullframe <- FALSE
+      if(full.args$fullframe & full.args$idata_method == 'm2') 
+        setfullframe <- TRUE
+      if(!full.args$fullframe) 
+        setfullframe <- FALSE
+      if(setfullframe) {
         uvarby <- model$model_info$univariate_by
         uvarbyresp <- paste0(uvarby, resp)
         uvarbynewdata <- eval(full.args$newdata) %>% 
