@@ -6,9 +6,15 @@
 #' 
 #' @param model An object of class \code{bgmfit}.
 #' 
-#' @inherit growthparameters.bgmfit params
-#' @inherit brms::pp_check.brmsfit params description 
-#' @inherit fitted_draws.bgmfit params
+#' @inheritParams growthparameters.bgmfit
+#' @inheritParams brms::pp_check.brmsfit
+#' @inheritParams fitted_draws.bgmfit
+#' @inheritParams bayesplot::ppc_dens_overlay
+#' @inheritParams bayesplot::ppc_ecdf_overlay
+#' @inheritParams bayesplot::ppc_freqpoly
+#' @inheritParams bayesplot::ppc_violin_grouped
+#' @inheritParams bayesplot::ppc_hist
+#' @inherit brms::pp_check.brmsfit description
 #' 
 #' @param ... Additional arguments passed to the [brms::pp_check.brmsfit()] 
 #' function. Please see [brms::pp_check.brmsfit()] for details.
@@ -24,12 +30,14 @@
 #' 
 #' # Fit Bayesian SITAR model 
 #' 
-#' # To avoid mode estimation which takes time, a model fitted to the 
-#' # 'berkeley_mdata' has already been saved as 'berkeley_mfit'. 
-#' # Details on 'berkeley_mdata' and 'berkeley_mfit' are provided in the 
-#' # 'bsitar' function.
+#' # To avoid mode estimation which takes time, the Bayesian SITAR model fit to 
+#' # the 'berkeley_exdata' has been saved as an example fit ('berkeley_exfit').
+#' # See 'bsitar' function for details on 'berkeley_exdata' and 'berkeley_exfit'.
 #' 
-#' model <- berkeley_mfit
+#' # Check and confirm whether model fit object 'berkeley_exfit' exists
+#'  berkeley_exfit <- getNsObject(berkeley_exfit)
+#' 
+#' model <- berkeley_exfit
 #' 
 #' plot_ppc(model, ndraws = 100)
 #' 
@@ -43,18 +51,66 @@ plot_ppc.bgmfit <-
            x = NULL,
            newdata = NULL,
            resp = NULL,
+           size = 0.25,
+           alpha = 0.7,
+           trim = FALSE,
+           bw = "nrd0",
+           adjust = 1,
+           kernel = "gaussian",
+           n_dens = 1024,
+           pad = TRUE,
+           discrete = FALSE,
+           binwidth = NULL,
+           bins = NULL,
+           breaks = NULL,
+           freq = TRUE,
+           y_draw = c("violin", "points", "both"),
+           y_size = 1,
+           y_alpha = 1,
+           y_jitter = 0.1,
            verbose = FALSE,
            deriv_model = NULL,
            dummy_to_factor = NULL, 
-           usesavedfuns = FALSE,
+           expose_function = FALSE,
+           usesavedfuns = NULL,
            clearenvfuns = NULL,
            envir = NULL,
            ...) {
     
     if(is.null(envir)) {
+      envir <- model$model_info$envir
+    } else {
       envir <- parent.frame()
     }
     
+
+    if(is.null(usesavedfuns)) {
+      if(!is.null(model$model_info$exefuns[[1]])) {
+        usesavedfuns <- TRUE
+      } else if(is.null(model$model_info$exefuns[[1]])) {
+        if(expose_function) {
+          model <- expose_model_functions(model, envir = envir)
+          usesavedfuns <- TRUE
+        } else if(!expose_function) {
+          usesavedfuns <- FALSE
+        }
+      }
+    } else { 
+      if(!usesavedfuns) {
+        if(expose_function) {
+          model <- expose_model_functions(model, envir = envir)
+          usesavedfuns <- TRUE
+        }
+      } else if(usesavedfuns) {
+        check_if_functions_exists(model, checks = TRUE, 
+                                  usesavedfuns = usesavedfuns)
+      }
+    }
+    
+    
+    check_if_package_installed(model, xcall = NULL)
+    
+    
     if(is.null(ndraws)) {
       ndraws <- brms::ndraws(model)
     }
@@ -93,7 +149,7 @@ plot_ppc.bgmfit <-
                                 xcall = match.call(),
                                 resp = resp,
                                 envir = envir,
-                                deriv = deriv, 
+                                deriv = 'deriv', 
                                 all = FALSE,
                                 verbose = verbose)
     
@@ -115,6 +171,20 @@ plot_ppc.bgmfit <-
     
     if(is.null(test)) return(invisible(NULL))
     
+    
+    if(!isTRUE(
+      check_pkg_version_exists('brms', 
+                               minversion = get_package_minversion('brms'), 
+                               prompt = FALSE,
+                               stop = FALSE,
+                               verbose = FALSE))) {
+      if(is.null(check_if_functions_exists(model, o, model$xcall,
+                                           usesavedfuns = usesavedfuns))) {
+        return(invisible(NULL))
+      }
+    }
+    
+    
     misc <- c("verbose", "usesavedfuns", "clearenvfuns", 
               "envir", "fullframe", "dummy_to_factor")
     calling.args <- post_processing_args_sanitize(model = model,
@@ -128,6 +198,10 @@ plot_ppc.bgmfit <-
    
     
     calling.args$object <- full.args$model
+    if(is.null(calling.args$newdata)) {
+      if(!is.null(newdata)) calling.args$newdata <- newdata
+    }
+   
     
     . <- do.call(brms::pp_check, calling.args)
     
@@ -144,6 +218,9 @@ plot_ppc.bgmfit <-
     }
     
     if(is.null(eval(full.args$clearenvfuns))) {
+      if(is.null(eval(full.args$usesavedfuns))) {
+        full.args$usesavedfuns <- usesavedfuns
+      }
       if(eval(full.args$usesavedfuns)) {
         setcleanup <- TRUE 
       } else {
@@ -153,18 +230,20 @@ plot_ppc.bgmfit <-
     
     # Cleanup environment if requested
     if(setcleanup) {
-      tempgenv <- envir
-      for (oalli in names(oall)) {
-        if(exists(oalli, envir = tempgenv )) {
-          remove(list=oalli, envir = tempgenv)
+      suppressWarnings({
+        tempgenv <- envir
+        for (oalli in names(oall)) {
+          if(exists(oalli, envir = tempgenv )) {
+            remove(list=oalli, envir = tempgenv)
+          }
         }
-      }
-      tempgenv <- test
-      for (oalli in names(oall)) {
-        if(exists(oalli, envir = tempgenv )) {
-          remove(list=oalli, envir = tempgenv)
+        tempgenv <- test
+        for (oalli in names(oall)) {
+          if(exists(oalli, envir = tempgenv )) {
+            remove(list=oalli, envir = tempgenv)
+          }
         }
-      }
+      })
     } # if(setcleanup) {
     
     .
